summaryrefslogtreecommitdiff
path: root/gcc/sched-int.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/sched-int.h')
-rw-r--r--gcc/sched-int.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/gcc/sched-int.h b/gcc/sched-int.h
index 10fd03c9f42..9077c881ce6 100644
--- a/gcc/sched-int.h
+++ b/gcc/sched-int.h
@@ -653,9 +653,9 @@ extern struct haifa_sched_info *current_sched_info;
up. */
extern bool sched_pressure_p;
/* Map regno -> its pressure class. The map defined only when
SCHED_PRESSURE_P is true. */
-extern enum reg_class *sched_regno_pressure_class;
+extern enum reg_class *sched_regno_cover_class;
/* Indexed by INSN_UID, the collection of all data associated with
a single instruction. */
@@ -707,7 +707,7 @@ struct _haifa_deps_insn_data
#define INCREASE_BITS 8
/* The structure describes how the corresponding insn increases the
- register pressure for each pressure class. */
+ register pressure for each cover class. */
struct reg_pressure_data
{
/* Pressure increase for given class because of clobber. */
@@ -736,7 +736,7 @@ struct reg_use_data
};
/* The following structure describes used sets of registers by insns.
- Registers are pseudos whose pressure class is not NO_REGS or hard
+ Registers are pseudos whose cover class is not NO_REGS or hard
registers available for allocations. */
struct reg_set_data
{
@@ -804,7 +804,7 @@ struct _haifa_insn_data
struct reg_pressure_data *reg_pressure;
/* The following array contains maximal reg pressure between last
scheduled insn and given insn. There is an element for each
- pressure class of pseudos referenced in insns. This info updated
+ cover class of pseudos referenced in insns. This info updated
after scheduling each insn for each insn between the two
mentioned insns. */
int *max_reg_pressure;
@@ -653,9 +653,9 @@ extern struct haifa_sched_info *current_sched_info;
up. */
extern bool sched_pressure_p;
-/* Map regno -> its pressure class. The map defined only when
+/* Map regno -> its cover class. The map defined only when
SCHED_PRESSURE_P is true. */